pub async fn short(our_args: ArgsOs) -> Result<()>Expand description
Lists commmits reachable from HEAD, but not from a specified base branch (which defaults to the local trunk).
TODO: Command-line arguments are fundamentally ffi::OsString, not
String. Converting the former to the latter and back, to build git(1)
range arguments, is potentially lossy. Avoid it by concatenating byte
encoded vectors rather than formatting strings.
Errors
Returns an error if the base branch is unspecified, and a trunk cannot be
identified; or, if git returns bad status.